---
title: Getting Started
---

<div class="grid cards" markdown>
-   __🚨 Breaking changes__

    ---
    
    UiPath Python SDK v2.2.0+ will introduce **breaking changes** starting **November 26, 2025**  
    [See Details](./core/release_notes.md)
</div>

<div class="grid cards" markdown>
-   __UiPath SDK__

    ---

    Code with full UiPath context to build custom automations and agents from the ground up.

    [Start Building](./core/getting_started.md)

</div>

<div class="grid cards" markdown>
-   __UiPath MCP SDK__

    ---

    Build and host Coded MCP Servers within UiPath.

    [Start Building](./mcp/quick_start.md)

</div>

<h2> Extensions </h2>
<div class="grid cards" markdown>
-   __UiPath Langchain SDK__

    ---

    Build enterprise-grade UiPath agents using the LangChain framework, with seamless integration from build to run.

    [Get Started](./langchain/quick_start.md)

-   __UiPath LlamaIndex SDK__

    ---

    Build enterprise-grade UiPath agents using the LlamaIndex framework, with seamless integration from build to run.

    [Get Started](./llamaindex/quick_start.md)

</div>
